SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE OR ALTER PROCEDURE [dbo].[GetTempDbUsage]
    @InstanceName NVARCHAR(100),
    @LinkedServerName NVARCHAR(128) = NULL
AS
BEGIN
    SET NOCOUNT ON;

    IF @LinkedServerName IS NULL
    BEGIN
        INSERT INTO dbo.TempDbUsage ([Date], InstanceName, [Name], UsedMB)
        SELECT 
            GETDATE(),
            @InstanceName,
            mf.name,
            (fsu.user_object_reserved_page_count + fsu.internal_object_reserved_page_count) * 8 / 1024 AS UsedMB
        FROM tempdb.sys.dm_db_file_space_usage fsu
        JOIN sys.master_files mf
            ON mf.database_id = DB_ID('tempdb')
            AND mf.file_id = fsu.file_id;
    END
    ELSE
    BEGIN
        CREATE TABLE #TempDbUsageLinked (
            [Name] SYSNAME,
            [UsedMB] INT
        );

        DECLARE @SQL NVARCHAR(MAX);

        SET @SQL = '
            INSERT INTO #TempDbUsageLinked
            SELECT 
                mf.name,
                (fsu.user_object_reserved_page_count + fsu.internal_object_reserved_page_count) * 8 / 1024 AS UsedMB
            FROM [' + @LinkedServerName + '].tempdb.sys.dm_db_file_space_usage fsu
            JOIN [' + @LinkedServerName + '].master.sys.master_files mf
                ON mf.database_id = DB_ID(''tempdb'')
                AND mf.file_id = fsu.file_id;';

        EXEC(@SQL);

        INSERT INTO dbo.TempDbUsage ([Date], InstanceName, [Name], UsedMB)
        SELECT GETDATE(), @InstanceName, [Name], UsedMB
        FROM #TempDbUsageLinked;

        DROP TABLE #TempDbUsageLinked;
    END
END;
GO