DECLARE @TargetDatabase SYSNAME = DB_NAME();
USE [msdb];

-- Vorhandenen Job lschen
IF EXISTS (SELECT 1 FROM msdb.dbo.sysjobs WHERE name = N'Maintenance - GetPerformanceIndicators for PerfGuard')
BEGIN
    EXEC msdb.dbo.sp_delete_job 
        @job_name = N'Maintenance - GetPerformanceIndicators for PerfGuard', 
        @delete_unused_schedule = 1;
END

DECLARE @ReturnCode INT = 0;
DECLARE @jobId BINARY(16);
DECLARE @Owner SYSNAME = SUSER_SNAME();

-- Kategorie anlegen
IF NOT EXISTS (
    SELECT 1 
    FROM msdb.dbo.syscategories 
    WHERE name = N'Data Collector' AND category_class = 1
)
BEGIN
    EXEC msdb.dbo.sp_add_category 
        @class = N'JOB', 
        @type = N'LOCAL', 
        @name = N'Data Collector';
END;

-- Job erstellen
EXEC @ReturnCode = msdb.dbo.sp_add_job 
    @job_name = N'Maintenance - GetPerformanceIndicators for PerfGuard',
    @enabled = 1,
    @notify_level_eventlog = 0,
    @delete_level = 0,
    @description = N'Gets performance indicators for PerfGuard

Schedule
Job runs every 15 minutes

History
2025.04.10 | GRI | Initial Creation
2025.04.11 | GRI | Added Get Query
2025.04.29 | GRI | Switched IndexesMissing to other job
2025.05.05 | GRI | Added PlanCache
2025.05.07 | GRI | Added VSS freezes

Contact
florian.grieme@gmx.de',
    @category_name = N'Data Collector',
    @owner_login_name = @Owner,
    @job_id = @jobId OUTPUT;

-- Step 1 - CPU
EXEC msdb.dbo.sp_add_jobstep @job_id = @jobId, @step_id = 1,
    @step_name = N'010 - Get CPU (Percentage used serverwide)',
    @subsystem = N'TSQL',
    @command = N'
SET ANSI_NULLS ON;
SET QUOTED_IDENTIFIER ON;

EXEC dbo.GetCpuPercentageUsed;',
    @database_name = @TargetDatabase,
    @on_success_action = 3;

-- Step 2 - RAM
EXEC msdb.dbo.sp_add_jobstep @job_id = @jobId, @step_id = 2,
    @step_name = N'020 - Get RAM (Percentage used serverwide)',
    @subsystem = N'TSQL',
    @command = N'
SET ANSI_NULLS ON;
SET QUOTED_IDENTIFIER ON;

EXEC dbo.GetRamPercentageUsed;',
    @database_name = @TargetDatabase,
    @on_success_action = 3;

EXEC msdb.dbo.sp_add_jobstep @job_id = @jobId, @step_id = 3,
    @step_name = N'030 - RAM Pressure & Grants (per Instance)',
    @subsystem = N'TSQL',
    @command = N'EXEC dbo.GetRamPressure;',
    @database_name = @TargetDatabase,
    @on_success_action = 3;

-- Step 4 - IO
EXEC msdb.dbo.sp_add_jobstep @job_id = @jobId, @step_id = 4,
    @step_name = N'040 - IO Reads/Writes (per Instance)',
    @subsystem = N'TSQL',
    @command = N'EXEC dbo.GetIo;',
    @database_name = @TargetDatabase,
    @on_success_action = 3;

EXEC msdb.dbo.sp_add_jobstep @job_id = @jobId, @step_id = 5,
    @step_name = N'050 - GetWaits',
    @subsystem = N'TSQL',
    @command = N'EXEC dbo.GetWaits;',
    @database_name = @TargetDatabase,
    @on_success_action = 3;

EXEC msdb.dbo.sp_add_jobstep @job_id = @jobId, @step_id = 6,
    @step_name = N'060 - TempDB IO',
    @subsystem = N'TSQL',
    @command = N'EXEC dbo.GetTempDbIo;',
    @database_name = @TargetDatabase,
    @on_success_action = 3;

EXEC msdb.dbo.sp_add_jobstep @job_id = @jobId, @step_id = 7,
    @step_name = N'070 - Sessions',
    @subsystem = N'TSQL',
    @command = N'EXEC dbo.GetSession;',
    @database_name = @TargetDatabase,
    @on_success_action = 3;

EXEC msdb.dbo.sp_add_jobstep @job_id = @jobId, @step_id = 8,
    @step_name = N'080 - Get Queries (per Instance)',
    @subsystem = N'TSQL',
    @command = N'EXEC dbo.GetQueries;',
    @database_name = @TargetDatabase,
    @on_success_action = 3;

-- Step 9 - PlanCache
EXEC msdb.dbo.sp_add_jobstep @job_id = @jobId, @step_id = 9,
    @step_name = N'090 - Get PlanCache (per Instance)',
    @subsystem = N'TSQL',
    @command = N'EXEC dbo.GetPlanCache;',
    @database_name = @TargetDatabase,
    @on_success_action = 3;

EXEC msdb.dbo.sp_add_jobstep @job_id = @jobId, @step_id = 10,
    @step_name = N'100 - Get Freezes',
    @subsystem = N'TSQL',
    @command = N'EXEC dbo.GetFreezes;',
    @database_name = @TargetDatabase,
    @on_success_action = 3;

-- Step 11 - Index Fillfactor < 100
EXEC msdb.dbo.sp_add_jobstep @job_id = @jobId, @step_id = 11,
    @step_name = N'110 - GetIndexFillFactor',
    @subsystem = N'TSQL',
    @command = N'EXEC dbo.GetIndexFillFactor;',
    @database_name = @TargetDatabase,
    @on_success_action = 3;

-- Step 12 - Heaps
EXEC msdb.dbo.sp_add_jobstep @job_id = @jobId, @step_id = 12,
    @step_name = N'120 - GetHeaps',
    @subsystem = N'TSQL',
    @command = N'EXEC dbo.GetHeaps;',
    @database_name = @TargetDatabase,
    @on_success_action = 3;

-- Step 13 - Index Duplicates
EXEC msdb.dbo.sp_add_jobstep @job_id = @jobId, @step_id = 13,
    @step_name = N'130 - GetIndexDuplicates ',
    @subsystem = N'TSQL',
    @command = N'EXEC dbo.GetIndexDuplicates;',
    @database_name = @TargetDatabase,
    @on_success_action = 3;

-- Step 14 - Index Missing
EXEC msdb.dbo.sp_add_jobstep @job_id = @jobId, @step_id = 14,
    @step_name = N'140 - GetIndexesMissing',
    @subsystem = N'TSQL',
    @command = N'EXEC dbo.GetIndexesMissing;',
    @database_name = @TargetDatabase,
    @on_success_action = 3;

-- Step 15 - Index Unnecessary
EXEC msdb.dbo.sp_add_jobstep @job_id = @jobId, @step_id = 15,
    @step_name = N'150 - GetIndexesUnnecessary',
    @subsystem = N'TSQL',
    @command = N'EXEC dbo.GetIndexesUnnecessary;',
    @database_name = @TargetDatabase,
    @on_success_action = 3;

EXEC msdb.dbo.sp_add_jobstep @job_id = @jobId, @step_id = 16,
    @step_name = N'160 - Get Statistics',
    @subsystem = N'TSQL',
    @command = N'EXEC dbo.GetStatistics;',
    @database_name = @TargetDatabase,
    @on_success_action = 3;

EXEC msdb.dbo.sp_add_jobstep @job_id = @jobId, @step_id = 17,
    @step_name = N'900 - Cleanup (older than 1 year)',
    @subsystem = N'TSQL',
    @command = N'
SET ANSI_NULLS ON;
SET QUOTED_IDENTIFIER ON;

EXEC dbo.sp_CleanupTelemetryData;',
    @database_name = @TargetDatabase,
    @on_success_action = 1;

-- Start Step definieren
EXEC msdb.dbo.sp_update_job 
    @job_id = @jobId, 
    @start_step_id = 1;

-- Zeitplan (alle 15 Minuten)
EXEC msdb.dbo.sp_add_jobschedule 
    @job_id = @jobId, 
    @name = N'Every 15 minutes',
    @enabled = 1,
    @freq_type = 4,
    @freq_interval = 1,
    @freq_subday_type = 4,
    @freq_subday_interval = 15,
    @active_start_date = 20250408,
    @active_end_date = 99991231,
    @active_start_time = 0,
    @active_end_time = 235959;

-- Jobserver setzen
EXEC msdb.dbo.sp_add_jobserver 
    @job_id = @jobId, 
    @server_name = N'(local)';

DECLARE @SQL NVARCHAR(MAX) = 'USE [' + @TargetDatabase + ']';
EXEC(@SQL);
GO