﻿DECLARE @TargetDatabase SYSNAME = DB_NAME();
USE [msdb];

-- Vorhandenen Job löschen
IF EXISTS (SELECT 1 FROM msdb.dbo.sysjobs WHERE name = N'Maintenance - GetPerformanceIndicators for PerfGuard (saturdays, 1600)')
BEGIN
    EXEC msdb.dbo.sp_delete_job 
        @job_name = N'Maintenance - GetPerformanceIndicators for PerfGuard (saturdays, 1600)', 
        @delete_unused_schedule = 1;
END

DECLARE @ReturnCode INT = 0;
DECLARE @jobId BINARY(16);
DECLARE @Owner SYSNAME = SUSER_SNAME();

-- Kategorie anlegen
IF NOT EXISTS (
    SELECT 1 
    FROM msdb.dbo.syscategories 
    WHERE name = N'Data Collector' AND category_class = 1
)
BEGIN
    EXEC msdb.dbo.sp_add_category 
        @class = N'JOB', 
        @type = N'LOCAL', 
        @name = N'Data Collector';
END;

-- Job erstellen
EXEC @ReturnCode = msdb.dbo.sp_add_job 
    @job_name = N'Maintenance - GetPerformanceIndicators for PerfGuard (saturdays, 1600)',
    @enabled = 1,
    @notify_level_eventlog = 0,
    @delete_level = 0,
    @description = N'Gets performance indicators for PerfGuard

Schedule
Job runs saturdays at 1600

History
2025.04.14 | GRI | Initial Creation

Contact
florian.grieme@gmx.de',
    @category_name = N'Data Collector',
    @owner_login_name = @Owner,
    @job_id = @jobId OUTPUT;

-- Step 2 - Statistics to be refreshed
EXEC msdb.dbo.sp_add_jobstep @job_id = @jobId, @step_id = 1,
    @step_name = N'020 - Get Statistics to be refreshed (per Instance)',
    @subsystem = N'TSQL',
    @command = N'
SET ANSI_NULLS ON;
SET QUOTED_IDENTIFIER ON;

EXEC dbo.GetStatisticsToBeRefreshed @InstanceName = N''Instanz1'';

DECLARE @Instance SYSNAME, @Linked SYSNAME;
DECLARE c CURSOR FOR
SELECT InstanceName, LinkedServerName FROM dbo.InstanceLinkedServerConfig WHERE IsActive = 1;
OPEN c; FETCH NEXT FROM c INTO @Instance, @Linked;
WHILE @@FETCH_STATUS = 0
BEGIN
    EXEC dbo.GetStatisticsToBeRefreshed @InstanceName = @Instance, @LinkedServerName = @Linked;
    FETCH NEXT FROM c INTO @Instance, @Linked;
END
CLOSE c; DEALLOCATE c;',
    @database_name = @TargetDatabase,
    @on_success_action = 3;

-- Step 10 - Cleanup
EXEC msdb.dbo.sp_add_jobstep @job_id = @jobId, @step_id = 2,
    @step_name = N'900 - Cleanup (older than 1 year)',
    @subsystem = N'TSQL',
    @command = N'
SET ANSI_NULLS ON;
SET QUOTED_IDENTIFIER ON;

EXEC dbo.sp_CleanupTelemetryData;',
    @database_name = @TargetDatabase,
    @on_success_action = 1;

-- Start Step definieren
EXEC msdb.dbo.sp_update_job 
    @job_id = @jobId, 
    @start_step_id = 1;

EXEC msdb.dbo.sp_add_jobschedule 
    @job_id = @jobId, 
    @name = N'Samstags um 16:00 Uhr',
    @enabled = 1,
    @freq_type = 8,               -- wöchentlich
    @freq_interval = 7,           -- Samstag (1 = So, ..., 7 = Sa)
    @freq_recurrence_factor = 1,  -- jede Woche
    @active_start_date = 20250412, -- Startdatum z. B. 12.04.2025 (Samstag)
    @active_end_date = 99991231,
    @active_start_time = 160000,   -- 16:00 Uhr
    @active_end_time = 235959;

-- Jobserver setzen
EXEC msdb.dbo.sp_add_jobserver 
    @job_id = @jobId, 
    @server_name = N'(local)';

DECLARE @SQL NVARCHAR(MAX) = 'USE [' + @TargetDatabase + ']';
EXEC(@SQL);
GO
