/*
Decription
Displays a minimal performance dashboard comparing two given points in time

Revision History
2025.03.25 | GRI | Script Creation

Point of Contact
florian.grieme@gmx.de

Dependencies
-
*/

USE [ProcsAndFuncs]
GO
/****** Object:  StoredProcedure [dbo].[sp_DashboardPerformance]    Script Date: 02.04.2025 07:35:10 ******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO

CREATE OR ALTER PROCEDURE [dbo].[PerfGuardDashboard]
    @StartOld DATETIME,
    @EndOld DATETIME,
    @StartNew DATETIME,
    @EndNew DATETIME,
    @ShowHints BIT = NULL,
    @ShowDetails BIT = NULL
AS
BEGIN
    SET NOCOUNT ON;

    DECLARE 
        @dateLastEdit DATETIME = CAST('04.04.2025' AS DATETIME),
        @cpuOld INT, @cpuNew INT, @cpuOldMax INT, @cpuNewMax INT,
        @ramOld INT, @ramNew INT, @ramOldMax INT, @ramNewMax INT,
        @pressureOld INT, @pressureNew INT,
        @readsDatabaseFilesOld DECIMAL(10,2), @readsDatabaseFilesNew DECIMAL(10,2), @ioDatabaseFilesOld DECIMAL(10,2), @ioDatabaseFilesOldMax DECIMAL(10,2),
        @writesDatabaseFilesOld DECIMAL(10,2), @writesDatabaseFilesNew DECIMAL(10,2), @ioDatabaseFilesNew DECIMAL(10,2), @ioDatabaseFilesNewMax DECIMAL(10,2),     
        @readsTempDbOld DECIMAL(10,2), @readsTempDbNew DECIMAL(10,2), @readsTempDbOldMax DECIMAL(10,2), @readsTempDbNewMax DECIMAL(10,2),
        @writesTempDbOld DECIMAL(10,2), @writesTempDbNew DECIMAL(10,2), @writesTempDbOldMax DECIMAL(10,2), @writesTempDbNewMax DECIMAL(10,2),
        @waitsTopType NVARCHAR(MAX), @waitsOld DECIMAL(10,2), @waitsNew DECIMAL(10,2);

    DROP TABLE IF EXISTS #DashboardErgebnisse;

    CREATE TABLE #DashboardErgebnisse (
            Ord INT,
			InstanceName NVARCHAR(MAX),
            Metrik NVARCHAR(MAX),
            Altwert DECIMAL(10,2),
            AltwertMax DECIMAL(10,2),
            Neuwert DECIMAL(10,2),
            NeuwertMax DECIMAL(10,2),
            Trend NVARCHAR(MAX),
            Ampel VARCHAR(MAX),
            AmpelMax VARCHAR(MAX),
            TopWaitType NVARCHAR(MAX),
            Hinweis NVARCHAR(MAX),
            Empfehlung NVARCHAR(MAX)
    );

    INSERT INTO #DashboardErgebnisse 
    SELECT 0, 'PerfGuard - SQL Performance Command Center', 'http://www.agileinformer.de', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL;

    -- CPU
WITH CpuMetrics AS (
    SELECT
        -- CPU
        AVG(CASE WHEN c.Date BETWEEN @StartOld AND @EndOld THEN c.PercentageUsedServer END) AS CpuOldAvg,
        MAX(CASE WHEN c.Date BETWEEN @StartOld AND @EndOld THEN c.PercentageUsedServer END) AS CpuOldMax,
        AVG(CASE WHEN c.Date BETWEEN @StartNew AND @EndNew THEN c.PercentageUsedServer END) AS CpuNewAvg,
        MAX(CASE WHEN c.Date BETWEEN @StartNew AND @EndNew THEN c.PercentageUsedServer END) AS CpuNewMax,

        -- RAM
        AVG(CASE WHEN r.Date BETWEEN @StartOld AND @EndOld THEN r.PercentageUsedServer END) AS RamOldAvg,
        MAX(CASE WHEN r.Date BETWEEN @StartOld AND @EndOld THEN r.PercentageUsedServer END) AS RamOldMax,
        AVG(CASE WHEN r.Date BETWEEN @StartNew AND @EndNew THEN r.PercentageUsedServer END) AS RamNewAvg,
        MAX(CASE WHEN r.Date BETWEEN @StartNew AND @EndNew THEN r.PercentageUsedServer END) AS RamNewMax
    FROM dbo.Cpu c
    CROSS JOIN dbo.Ram r
)
SELECT 
    @cpuOld     = CpuOldAvg,
    @cpuOldMax  = CpuOldMax,
    @cpuNew     = CpuNewAvg,
    @cpuNewMax  = CpuNewMax,

    @ramOld     = RamOldAvg,
    @ramOldMax  = RamOldMax,
    @ramNew     = RamNewAvg,
    @ramNewMax  = RamNewMax
FROM CpuMetrics;

    -- RAM-Pressure
    SELECT @pressureOld = ISNULL(MAX(Pressure), 0) + ISNULL(MAX(GrantsPending), 0) FROM dbo.RamPressure WHERE Date BETWEEN @StartOld AND @EndOld;
    SELECT @pressureNew = ISNULL(MAX(Pressure), 0) + ISNULL(MAX(GrantsPending), 0) FROM dbo.RamPressure WHERE Date BETWEEN @StartNew AND @EndNew;

    -- IO
    SELECT @readsDatabaseFilesOld = AVG(AverageReads), @writesDatabaseFilesOld = AVG(AverageWrites) FROM dbo.Io WHERE Date BETWEEN @StartOld AND @EndOld;
    SELECT @readsDatabaseFilesNew = AVG(AverageReads), @writesDatabaseFilesNew = AVG(AverageWrites) FROM dbo.Io WHERE Date BETWEEN @StartNew AND @EndNew;
    SET @ioDatabaseFilesOld = (@readsDatabaseFilesOld + @writesDatabaseFilesOld) / 2;
    SET @ioDatabaseFilesNew = (@readsDatabaseFilesNew + @writesDatabaseFilesNew) / 2;
    SELECT @ioDatabaseFilesOldMax = MAX(AverageWrites) FROM dbo.Io WHERE Date BETWEEN @StartOld AND @EndOld;
    SELECT @ioDatabaseFilesNewMax = MAX(AverageWrites) FROM dbo.Io WHERE Date BETWEEN @StartNew AND @EndNew;

    -- TempDB I/O
    ;WITH TempDbAggOld AS (
    SELECT 
        AVG(AvgReadMs) AS ReadAvg,
        MAX(AvgReadMs) AS ReadMax,
        AVG(AvgWriteMs) AS WriteAvg,
        MAX(AvgWriteMs) AS WriteMax
    FROM dbo.TempDbIo
    WHERE Date BETWEEN @StartOld AND @EndOld
),
TempDbAggNew AS (
    SELECT 
        AVG(AvgReadMs) AS ReadAvg,
        MAX(AvgReadMs) AS ReadMax,
        AVG(AvgWriteMs) AS WriteAvg,
        MAX(AvgWriteMs) AS WriteMax
    FROM dbo.TempDbIo
    WHERE Date BETWEEN @StartNew AND @EndNew
)
SELECT 
    @readsTempDbOld = o.ReadAvg,
    @readsTempDbOldMax = o.ReadMax,
    @writesTempDbOld = o.WriteAvg,
    @writesTempDbOldMax = o.WriteMax,
    @readsTempDbNew = n.ReadAvg,
    @readsTempDbNewMax = n.ReadMax,
    @writesTempDbNew = n.WriteAvg,
    @writesTempDbNewMax = n.WriteMax
FROM TempDbAggOld o, TempDbAggNew n;

    -- Wait Stats
    ;WITH RelevanteWaits AS (
        SELECT WaitType, AVG(AvgWaitMs) AS AvgWaitMs
        FROM dbo.Wait
        WHERE Date BETWEEN @StartNew AND @EndNew
		AND WaitType IN (SELECT WaitType FROM WhiteListWaitType)
        GROUP BY WaitType
    )
    SELECT TOP 1 @waitsTopType = WaitType, @waitsNew = AvgWaitMs FROM RelevanteWaits ORDER BY AvgWaitMs DESC;

    SELECT @waitsOld = AVG(AvgWaitMs) FROM dbo.Wait WHERE Date BETWEEN @StartOld AND @EndOld AND WaitType = @waitsTopType;

    -- Serverbasierte Metriken hinzufgen
	INSERT INTO #DashboardErgebnisse

    SELECT
        1,
		'Server' AS InstanceName,
        dbo.GetMetricTextByMetricName('CPU'),
        ROUND(@cpuOld, 2) AS Altwert,
        ROUND(@cpuOldMax, 2) AS AltwertMax,
        ROUND(@cpuNew, 2) AS Neuwert,
        ROUND(@cpuNewMax, 2) AS NeuwertMax,
        dbo.GetTrend(@cpuOld, @cpuNew),
        dbo.GetTrafficLightIndicatorStringByMetric('CPU', CAST(@cpuNew AS INT)) AS Ampel,
        dbo.GetTrafficLightIndicatorStringByMetric('CPU', CAST(@cpuNewMax AS INT)) AmpelMax,
        NULL AS TopWaitType,
        dbo.GetMetricDescriptionByMetric('CPU'),
        dbo.GetHintByMetricName('CPU')

    UNION ALL

    SELECT
        2,
        'Server' AS InstanceName,
        dbo.GetMetricTextByMetricName('RAM'), 
        ROUND(@ramOld, 2), 
        ROUND(@ramOldMax, 2), 
        ROUND(@ramNew, 2), 
        ROUND(@ramNewMax, 2), 
        dbo.GetTrend(@ramOld, @ramNew),
        dbo.GetTrafficLightIndicatorStringByMetric('RAM', CAST(@ramNew AS INT)),
        dbo.GetTrafficLightIndicatorStringByMetric('RAM', CAST(@ramNewMax AS INT)),
        NULL, 
        dbo.GetMetricDescriptionByMetric('RAM'), 
        dbo.GetHintByMetricName('RAM')

    UNION ALL

    SELECT 
        3,
        'Instanzen (Gesamt)' AS InstanceName, 
        dbo.GetMetricTextByMetricName('Pressure'), 
        @pressureOld, 
        @pressureOld, 
        @pressureNew, 
        @pressureNew, 
        dbo.GetTrend(@pressureOld, @pressureNew), 
        dbo.GetTrafficLightIndicatorStringByMetric('Pressure', @pressureNew), 
        dbo.GetTrafficLightIndicatorStringByMetric('Pressure', @pressureNew),
        NULL,
        dbo.GetMetricDescriptionByMetric('Pressure'),
        dbo.GetHintByMetricName('Pressure')
    
    UNION ALL
    
    SELECT 
        4,
        'Instanzen (Gesamt)' AS InstanceName, 
        dbo.GetMetricTextByMetricName('IO'), 
        ROUND(@ioDatabaseFilesOld, 2), 
        @ioDatabaseFilesOldMax, 
        ROUND(@ioDatabaseFilesNew, 2), 
        @ioDatabaseFilesNewMax, 
        dbo.GetTrend(@ioDatabaseFilesOld, @ioDatabaseFilesNew), 
        dbo.GetTrafficLightIndicatorStringByMetric('IO', CAST(@ioDatabaseFilesNew AS INT)), 
        dbo.GetTrafficLightIndicatorStringByMetric('IO', CAST(@ioDatabaseFilesNewMax AS INT)),
        NULL, 
        dbo.GetMetricDescriptionByMetric('IO'), 
        dbo.GetHintByMetricName('IO')

    UNION ALL

    SELECT 
        5,
        'Instanzen (Gesamt)' AS InstanceName, 
        dbo.GetMetricTextByMetricName('TempDBRead'), 
        ROUND(@readsTempDbOld, 2), 
        @readsTempDbOldMax, 
        ROUND(@readsTempDbNew, 2), 
        @readsTempDbNewMax, 
        dbo.GetTrend(@readsTempDbOld, @readsTempDbNew), 
        dbo.GetTrafficLightIndicatorStringByMetric('TempDBRead', CAST(@readsTempDbNew AS INT)), 
        dbo.GetTrafficLightIndicatorStringByMetric('TempDBRead', CAST(@readsTempDbNewMax AS INT)),
        NULL,
        dbo.GetMetricDescriptionByMetric('TempDBRead'), 
        dbo.GetHintByMetricName('TempDBRead')

    UNION ALL

    SELECT
        6,
        'Instanzen (Gesamt)' AS InstanceName, 
        dbo.GetMetricTextByMetricName('TempDBWrite'),
        ROUND(@writesTempDbOld, 2), 
        @writesTempDbOldMax, 
        ROUND(@writesTempDbNew, 2), 
        @writesTempDbNewMax, 
        dbo.GetTrend(@writesTempDbOld, @writesTempDbNew), 
        dbo.GetTrafficLightIndicatorStringByMetric('TempDBWrite', CAST(@writesTempDbNew AS INT)), 
        dbo.GetTrafficLightIndicatorStringByMetric('TempDBWrite', CAST(@writesTempDbNewMax AS INT)), 
        NULL,
        dbo.GetMetricDescriptionByMetric('TempDBWrite'), 
        dbo.GetHintByMetricName('TempDBWrite')

    UNION ALL

    SELECT 
        7,
        'Instanzen (Gesamt)' AS InstanceName, 
        dbo.GetMetricTextByMetricName('WaitStats'),
        ROUND(@waitsOld, 2), 
        ROUND(@waitsOld, 2), 
        ROUND(@waitsNew, 2), 
        ROUND(@waitsNew, 2), 
        dbo.GetTrend(@waitsOld, @waitsNew),  
        dbo.GetTrafficLightIndicatorStringByMetric('WaitStats', CAST(@waitsNew AS INT)),
        dbo.GetTrafficLightIndicatorStringByMetric('WaitStats', CAST(@waitsNew AS INT)),
        @waitsTopType, 
        dbo.GetMetricDescriptionByMetric('WaitStats'), 
        dbo.GetWaitTypeExplanation(@waitsTopType, @waitsNew);

    IF (@ShowDetails = 0 AND @ShowHints = 1)
    BEGIN
        SELECT
            InstanceName,
            Metrik,
            Altwert,
            AltwertMax,
            Neuwert,
            NeuwertMax,
            Trend,
            Ampel,
            AmpelMax,
            Hinweis,
            Empfehlung
        FROM #DashboardErgebnisse
        ORDER BY Ord, InstanceName;
        DROP TABLE #DashboardErgebnisse;
        PRINT '@ShowDetails= ''' + CAST(@ShowDetails AS CHAR(1)) + '''' + ', @ShowHints= ''' + CAST(@ShowHints AS CHAR(1)) + '''';
        RETURN;
    END

    IF (@ShowDetails = 0 AND @ShowHints = 0)
    BEGIN
        SELECT
            Metrik,
            Altwert,
            AltwertMax,
            Neuwert,
            NeuwertMax,
            Trend,
            Ampel,
            AmpelMax
        FROM #DashboardErgebnisse
        ORDER BY Ord, InstanceName;
        DROP TABLE #DashboardErgebnisse;
        PRINT '@ShowDetails= ''' + CAST(@ShowDetails AS CHAR(1)) + '''' + ', @ShowHints= ''' + CAST(@ShowHints AS CHAR(1)) + '''';
        RETURN;
    END


	-- Instanzbasierte Metriken hinzufgen
    INSERT INTO #DashboardErgebnisse
    SELECT 
        8,
        InstanceName,
        dbo.GetMetricTextByMetricName('Pressure'),
        ROUND(AVG(CASE WHEN Date BETWEEN @StartOld AND @EndOld THEN CAST(Pressure AS FLOAT) END) * 100, 2),
        ROUND(AVG(CASE WHEN Date BETWEEN @StartOld AND @EndOld THEN CAST(Pressure AS FLOAT) END) * 100, 2), 
        ROUND(AVG(CASE WHEN Date BETWEEN @StartNew AND @EndNew THEN CAST(Pressure AS FLOAT) END) * 100, 2),
        ROUND(AVG(CASE WHEN Date BETWEEN @StartNew AND @EndNew THEN CAST(Pressure AS FLOAT) END) * 100, 2),
        dbo.GetTrend(ROUND(AVG(CASE WHEN Date BETWEEN @StartOld AND @EndOld THEN CAST(Pressure AS FLOAT) END) * 100, 2), ROUND(AVG(CASE WHEN Date BETWEEN @StartNew AND @EndNew THEN CAST(Pressure AS FLOAT) END) * 100, 2)),
        dbo.GetTrafficLightIndicatorStringByMetric('Pressue', ROUND(AVG(CASE WHEN Date BETWEEN @StartNew AND @EndNew THEN CAST(Pressure AS FLOAT) END) * 100, 2)),
        dbo.GetTrafficLightIndicatorStringByMetric('Pressue', ROUND(AVG(CASE WHEN Date BETWEEN @StartNew AND @EndNew THEN CAST(Pressure AS FLOAT) END) * 100, 2)),
        NULL,
        dbo.GetMetricDescriptionByMetric('Pressure'),
        dbo.GetHintByMetricName('Pressure')
    FROM dbo.RamPressure
    WHERE Date BETWEEN @StartOld AND @EndNew
    GROUP BY InstanceName

    UNION ALL

    SELECT 
        9,
        InstanceName,
        dbo.GetMetricTextByMetricName('IO'),
        ROUND(AVG(CASE WHEN Date BETWEEN @StartOld AND @EndOld THEN (AverageReads + AverageWrites) / 2 END), 2),
        ROUND(MAX(CASE WHEN Date BETWEEN @StartOld AND @EndOld THEN (AverageReads + AverageWrites) / 2 END), 2), 
        ROUND(AVG(CASE WHEN Date BETWEEN @StartNew AND @EndNew THEN (AverageReads + AverageWrites) / 2 END), 2),
        ROUND(MAX(CASE WHEN Date BETWEEN @StartNew AND @EndNew THEN (AverageReads + AverageWrites) / 2 END), 2),
        dbo.GetTrend(ROUND(AVG(CASE WHEN Date BETWEEN @StartOld AND @EndOld THEN (AverageReads + AverageWrites) / 2 END), 2), ROUND(AVG(CASE WHEN Date BETWEEN @StartNew AND @EndNew THEN (AverageReads + AverageWrites) / 2 END), 2)),
        dbo.GetTrafficLightIndicatorStringByMetric('IO', ROUND(AVG(CASE WHEN Date BETWEEN @StartNew AND @EndNew THEN (AverageReads + AverageWrites) / 2 END), 2)),
        dbo.GetTrafficLightIndicatorStringByMetric('IO', ROUND(MAX(CASE WHEN Date BETWEEN @StartNew AND @EndNew THEN (AverageReads + AverageWrites) / 2 END), 2)),
        NULL,
        dbo.GetMetricDescriptionByMetric('IO'),
        dbo.GetHintByMetricName('IO')
    FROM dbo.Io
    WHERE Date BETWEEN @StartOld AND @EndNew
    GROUP BY InstanceName

    UNION ALL

    SELECT 
        10,
        InstanceName,
        dbo.GetMetricTextByMetricName('TempDBRead'),
        ROUND(AVG(CASE WHEN Date BETWEEN @StartOld AND @EndOld THEN AvgReadMs END), 2),
        ROUND(MAX(CASE WHEN Date BETWEEN @StartOld AND @EndOld THEN AvgReadMs END), 2), 
        ROUND(AVG(CASE WHEN Date BETWEEN @StartNew AND @EndNew THEN AvgReadMs END), 2),
        ROUND(MAX(CASE WHEN Date BETWEEN @StartNew AND @EndNew THEN AvgReadMs END), 2),
        dbo.GetTrend(ROUND(AVG(CASE WHEN Date BETWEEN @StartOld AND @EndOld THEN AvgReadMs END), 2), ROUND(AVG(CASE WHEN Date BETWEEN @StartNew AND @EndNew THEN AvgReadMs END), 2)),
        dbo.GetTrafficLightIndicatorStringByMetric('TempDBRead', ROUND(AVG(CASE WHEN Date BETWEEN @StartNew AND @EndNew THEN AvgReadMs END), 2)),
        dbo.GetTrafficLightIndicatorStringByMetric('TempDBRead', ROUND(MAX(CASE WHEN Date BETWEEN @StartNew AND @EndNew THEN AvgReadMs END), 2)),
        NULL,
        dbo.GetMetricDescriptionByMetric('TempDBRead'),
        dbo.GetHintByMetricName('TempDBRead')
    FROM dbo.TempDbIo
    WHERE Date BETWEEN @StartOld AND @EndNew
    GROUP BY InstanceName

    UNION ALL

    SELECT 
        11,
        InstanceName,
        dbo.GetMetricTextByMetricName('TempDBWrite'),
        ROUND(AVG(CASE WHEN Date BETWEEN @StartOld AND @EndOld THEN AvgWriteMs END), 2),
        ROUND(MAX(CASE WHEN Date BETWEEN @StartOld AND @EndOld THEN AvgWriteMs END), 2), 
        ROUND(AVG(CASE WHEN Date BETWEEN @StartNew AND @EndNew THEN AvgWriteMs END), 2),
        ROUND(MAX(CASE WHEN Date BETWEEN @StartNew AND @EndNew THEN AvgWriteMs END), 2),
        dbo.GetTrend(ROUND(AVG(CASE WHEN Date BETWEEN @StartOld AND @EndOld THEN AvgWriteMs END), 2), ROUND(AVG(CASE WHEN Date BETWEEN @StartNew AND @EndNew THEN AvgWriteMs END), 2)),
        dbo.GetTrafficLightIndicatorStringByMetric('TempDBWrite', ROUND(AVG(CASE WHEN Date BETWEEN @StartNew AND @EndNew THEN AvgWriteMs END), 2)),
        dbo.GetTrafficLightIndicatorStringByMetric('TempDBWrite', ROUND(MAX(CASE WHEN Date BETWEEN @StartNew AND @EndNew THEN AvgWriteMs END), 2)),
        NULL,
        dbo.GetMetricDescriptionByMetric('TempDBWrite'),
        dbo.GetHintByMetricName('TempDBRead')
    FROM dbo.TempDbIo
    WHERE Date BETWEEN @StartOld AND @EndNew
    GROUP BY InstanceName

    UNION ALL

        SELECT 
    12,
    InstanceName,
    dbo.GetMetricTextByMetricName('TempDbUsage'),
    --ROUND(AVG(CASE WHEN [Date] BETWEEN @StartOld AND @EndOld THEN UsedMB END), 2),
    NULL,
    ROUND(MAX(CASE WHEN [Date] BETWEEN @StartOld AND @EndOld THEN UsedMB END), 2), 
    --ROUND(AVG(CASE WHEN [Date] BETWEEN @StartNew AND @EndNew THEN UsedMB END), 2),
    NULL,
    ROUND(MAX(CASE WHEN [Date] BETWEEN @StartNew AND @EndNew THEN UsedMB END), 2),
    dbo.GetTrend(ROUND(MAX(CASE WHEN [Date] BETWEEN @StartOld AND @EndOld THEN UsedMB END), 2), ROUND(MAX(CASE WHEN [Date] BETWEEN @StartNew AND @EndNew THEN UsedMB END), 2)),
    --dbo.GetTrafficLightIndicatorStringByMetric('TempDbUsage', ROUND(AVG(CASE WHEN [Date] BETWEEN @StartNew AND @EndNew THEN UsedMB END), 2)),
    --dbo.GetTrafficLightIndicatorStringByMetric('TempDbUsage', ROUND(MAX(CASE WHEN [Date] BETWEEN @StartNew AND @EndNew THEN UsedMB END), 2)),
    NULL,
    NULL,
    NULL,
    dbo.GetMetricDescriptionByMetric('TempDbUsage'),
    dbo.GetHintByMetricName('TempDbUsage')
    FROM dbo.TempDbUsage
    WHERE [Date] BETWEEN @StartOld AND @EndNew
    GROUP BY InstanceName

    UNION ALL

    SELECT 
        13,
        i.InstanceName,
        dbo.GetMetricTextByMetricName('WaitStats'),
        ROUND(AVG(CASE WHEN Date BETWEEN @StartOld AND @EndOld THEN AvgWaitMs END), 2),
        ROUND(MAX(CASE WHEN Date BETWEEN @StartOld AND @EndOld THEN AvgWaitMs END), 2), 
        ROUND(AVG(CASE WHEN Date BETWEEN @StartNew AND @EndNew THEN AvgWaitMs END), 2),
        ROUND(MAX(CASE WHEN Date BETWEEN @StartNew AND @EndNew THEN AvgWaitMs END), 2),
        dbo.GetTrend(ROUND(AVG(CASE WHEN Date BETWEEN @StartOld AND @EndOld THEN AvgWaitMs END), 2), ROUND(AVG(CASE WHEN Date BETWEEN @StartNew AND @EndNew THEN AvgWaitMs END), 2)),
        dbo.GetTrafficLightIndicatorStringByMetric('WaitStats', ROUND(AVG(CASE WHEN Date BETWEEN @StartNew AND @EndNew THEN AvgWaitMs END), 2)),
        dbo.GetTrafficLightIndicatorStringByMetric('WaitStats', ROUND(MAX(CASE WHEN Date BETWEEN @StartNew AND @EndNew THEN AvgWaitMs END), 2)),
        MAX(CASE WHEN Date BETWEEN @StartNew AND @EndNew THEN WaitType END),
        dbo.GetMetricDescriptionByMetric('WaitStats'),
        dbo.GetWaitTypeExplanation(MAX(CASE WHEN Date BETWEEN @StartNew AND @EndNew THEN WaitType END), ROUND(AVG(CASE WHEN Date BETWEEN @StartNew AND @EndNew THEN AvgWaitMs END), 2))
    FROM (SELECT DISTINCT InstanceName FROM dbo.Wait) i
	LEFT JOIN dbo.Wait w ON w.InstanceName = i.InstanceName AND w.WaitType IN (SELECT WaitType FROM dbo.WhiteListWaitType) AND w.Date BETWEEN @StartOld AND @EndNew
    GROUP BY i.InstanceName

    UNION ALL 

    SELECT 14, 'Version vom ' + FORMAT(@dateLastEdit, 'dd.MM.yyyy', 'de-DE'), 'http://www.agileinformer.de', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL;

    IF (DATEADD(mm, -6, GETDATE()) > @dateLastEdit)
    BEGIN
        INSERT INTO #DashboardErgebnisse
        SELECT 0, 'ACHTUNG! Alte Version -> DOWNLOAD ->', 'http://www.agileinformer.de', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL;
    END

    IF (@ShowHints = 1)
        BEGIN
            SELECT
                InstanceName,
                Metrik,
                Altwert,
                AltwertMax,
                Neuwert,
                NeuwertMax,
                Trend,
                Ampel,
                AmpelMax,
                Hinweis,
                Empfehlung
            FROM #DashboardErgebnisse
            ORDER BY Ord, InstanceName;
            PRINT '@ShowDetails= ''' + CAST(@ShowDetails AS CHAR(1)) + '''' + ', @ShowHints= ''' + CAST(@ShowHints AS CHAR(1)) + '''';
        END
    ELSE
        BEGIN
            SELECT
                InstanceName,
                Metrik,
                Altwert,
                AltwertMax,
                Neuwert,
                NeuwertMax,
                Trend,
                Ampel,
                AmpelMax
            FROM #DashboardErgebnisse
            ORDER BY Ord, InstanceName;
            PRINT '@ShowDetails= ''' + CAST(@ShowDetails AS CHAR(1)) + '''' + ', @ShowHints= ''' + CAST(@ShowHints AS CHAR(1)) + '''';
        END

    DROP TABLE #DashboardErgebnisse;
END;