SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO

CREATE OR ALTER PROCEDURE [dbo].[GetIo]
AS
BEGIN
    SET NOCOUNT ON;

    DECLARE 
        @TotalReads BIGINT = 0,
        @TotalReadStall BIGINT = 0,
        @TotalWrites BIGINT = 0,
        @TotalWriteStall BIGINT = 0,
        @ReadsAverage INT = 0,
        @WritesAverage INT = 0,
        @ReadsMax INT = 0,
        @WritesMax INT = 0,
        @dbid INT,
        @ReadsDB INT,
        @WritesDB INT;

    DECLARE db_cursor CURSOR FOR
    SELECT database_id
    FROM sys.databases
    WHERE database_id > 4 AND state = 0 AND is_read_only = 0 AND source_database_id IS NULL;

    OPEN db_cursor;
    FETCH NEXT FROM db_cursor INTO @dbid;

    WHILE @@FETCH_STATUS = 0
    BEGIN
        SELECT 
            @ReadsDB = CASE 
                          WHEN SUM(num_of_reads) > 0 THEN CEILING(SUM(io_stall_read_ms * 1.0) / SUM(num_of_reads)) 
                          ELSE 0 
                      END,
            @WritesDB = CASE 
                          WHEN SUM(num_of_writes) > 0 THEN CEILING(SUM(io_stall_write_ms * 1.0) / SUM(num_of_writes)) 
                          ELSE 0 
                       END,
            @TotalReads = @TotalReads + ISNULL(SUM(num_of_reads), 0),
            @TotalReadStall = @TotalReadStall + ISNULL(SUM(io_stall_read_ms), 0),
            @TotalWrites = @TotalWrites + ISNULL(SUM(num_of_writes), 0),
            @TotalWriteStall = @TotalWriteStall + ISNULL(SUM(io_stall_write_ms), 0)
        FROM sys.dm_io_virtual_file_stats(@dbid, NULL);

        IF @ReadsDB > @ReadsMax SET @ReadsMax = @ReadsDB;
        IF @WritesDB > @WritesMax SET @WritesMax = @WritesDB;

        FETCH NEXT FROM db_cursor INTO @dbid;
    END

    CLOSE db_cursor;
    DEALLOCATE db_cursor;

    SET @ReadsAverage = CASE 
                            WHEN @TotalReads > 0 THEN CEILING(@TotalReadStall * 1.0 / @TotalReads) 
                            ELSE 0 
                        END;

    SET @WritesAverage = CASE 
                            WHEN @TotalWrites > 0 THEN CEILING(@TotalWriteStall * 1.0 / @TotalWrites) 
                            ELSE 0 
                         END;

    INSERT INTO dbo.Io (Date, ReadsAverage, WritesAverage, ReadsMax, WritesMax)
    VALUES (GETDATE(), @ReadsAverage, @WritesAverage, @ReadsMax, @WritesMax);
END
GO