SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO

CREATE OR ALTER PROCEDURE [dbo].[GetIndexesMissing]
AS
BEGIN
    SET NOCOUNT ON;

    DECLARE 
        @sql NVARCHAR(MAX),
        @db NVARCHAR(255),
        @escapedDb NVARCHAR(200);

    IF OBJECT_ID('tempdb..##MissingIndexCounts') IS NOT NULL DROP TABLE ##MissingIndexCounts;

    CREATE TABLE ##MissingIndexCounts (
        DatabaseName NVARCHAR(128),
        MissingIndexCount INT
    );

    DECLARE db_cursor CURSOR FOR
    SELECT name FROM sys.databases
    WHERE state = 0 AND name NOT IN ('master','model','msdb','tempdb');

    OPEN db_cursor
    FETCH NEXT FROM db_cursor INTO @db

    WHILE @@FETCH_STATUS = 0
    BEGIN
        SET @escapedDb = REPLACE(@db, '''', '''''');

        SET @sql = '
        USE ' + QUOTENAME(@db) + ';
        INSERT INTO ##MissingIndexCounts (DatabaseName, MissingIndexCount)
        SELECT 
            ''' + @escapedDb + ''',
            COUNT(*)
        FROM sys.dm_db_missing_index_groups mig
        JOIN sys.dm_db_missing_index_group_stats migs ON mig.index_group_handle = migs.group_handle
        JOIN sys.dm_db_missing_index_details mid ON mig.index_handle = mid.index_handle
        WHERE mid.database_id = DB_ID()
          AND (migs.avg_total_user_cost * migs.avg_user_impact) * 
              (migs.user_seeks + migs.user_scans) > 1000000;';

        EXEC (@sql)
        FETCH NEXT FROM db_cursor INTO @db
    END

    CLOSE db_cursor
    DEALLOCATE db_cursor;

    DECLARE @avg INT, @max INT;

    SELECT 
        @avg = CEILING(AVG(CAST(MissingIndexCount AS FLOAT))),
        @max = MAX(MissingIndexCount)
    FROM ##MissingIndexCounts;

    INSERT INTO dbo.IndexMissing (Average, Max)
    VALUES (@avg, @max);

    DROP TABLE ##MissingIndexCounts;
END
GO