SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO

CREATE OR ALTER PROCEDURE [dbo].[GetIndexesUnnecessary]
AS
BEGIN
    SET NOCOUNT ON;

    DECLARE 
        @sql NVARCHAR(MAX),
        @db NVARCHAR(255),
        @escapedDb NVARCHAR(200);

    IF OBJECT_ID('tempdb..##UnnecessaryIndexCounts') IS NOT NULL DROP TABLE ##UnnecessaryIndexCounts;

    CREATE TABLE ##UnnecessaryIndexCounts (
        DatabaseName NVARCHAR(128),
        UnusedIndexCount INT
    );

    DECLARE db_cursor CURSOR FOR
    SELECT name FROM sys.databases
    WHERE 
        state = 0
        AND name NOT IN ('master', 'model', 'msdb', 'tempdb')
        AND source_database_id IS NULL
        AND is_read_only = 0
        AND is_distributor = 0;

    OPEN db_cursor
    FETCH NEXT FROM db_cursor INTO @db

    WHILE @@FETCH_STATUS = 0
    BEGIN
        SET @escapedDb = REPLACE(@db, '''', '''''');

        SET @sql = '
        USE ' + QUOTENAME(@db) + ';
        INSERT INTO ##UnnecessaryIndexCounts (DatabaseName, UnusedIndexCount)
        SELECT 
            ''' + @escapedDb + ''',
            COUNT(*)
        FROM sys.indexes i
        LEFT JOIN sys.dm_db_index_usage_stats us
            ON us.object_id = i.object_id AND us.index_id = i.index_id AND us.database_id = DB_ID()
        JOIN sys.objects o ON o.object_id = i.object_id
        WHERE 
            OBJECTPROPERTY(i.object_id, ''IsUserTable'') = 1
            AND i.index_id > 0
            AND i.is_primary_key = 0
            AND i.is_unique_constraint = 0
            AND i.is_disabled = 0
            AND ISNULL(us.user_seeks, 0) = 0
            AND ISNULL(us.user_scans, 0) = 0
            AND ISNULL(us.user_lookups, 0) = 0
            AND ISNULL(us.user_updates, 0) > 0
            AND i.name IS NOT NULL
            AND i.name NOT LIKE ''%FK%''
            AND o.is_ms_shipped = 0
            AND NOT EXISTS (
                SELECT 1
                FROM ' + QUOTENAME(DB_NAME()) + '.dbo.BlacklistIndexTable bl
                WHERE bl.DatabaseName = ''' + @escapedDb + '''
                AND bl.TableName = OBJECT_NAME(i.object_id)
            );';

        EXEC (@sql)
        FETCH NEXT FROM db_cursor INTO @db
    END

    CLOSE db_cursor
    DEALLOCATE db_cursor;

    DECLARE @avg INT, @max INT;

    SELECT 
        @avg = CEILING(AVG(CAST(UnusedIndexCount AS FLOAT))),
        @max = MAX(UnusedIndexCount)
    FROM ##UnnecessaryIndexCounts;

    INSERT INTO dbo.IndexUnnecessary (Average, Max)
    VALUES (@avg, @max);

    DROP TABLE ##UnnecessaryIndexCounts;
END
GO