SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO

CREATE OR ALTER PROCEDURE [dbo].[GetStatistics]
AS
BEGIN
    SET NOCOUNT ON;

    DECLARE 
        @sql NVARCHAR(MAX),
        @db NVARCHAR(255),
        @avg INT;

    DECLARE @Results TABLE (CountValue INT);

    DECLARE db_cursor CURSOR FOR
    SELECT name FROM sys.databases
    WHERE state = 0
      AND name NOT IN ('master','model','msdb','tempdb')
      AND source_database_id IS NULL
      AND is_read_only = 0
      AND is_distributor = 0;

    OPEN db_cursor
    FETCH NEXT FROM db_cursor INTO @db

    WHILE @@FETCH_STATUS = 0
    BEGIN
        SET @sql = '
        USE ' + QUOTENAME(@db) + ';
        SELECT ISNULL(COUNT(CASE 
            WHEN sp.last_updated <= DATEADD(DAY, -7, GETDATE()) 
                 AND sp.modification_counter > (ISNULL(sp.rows, 0) * 0.2) 
            THEN 1 END), 0)
        FROM sys.stats AS st
        INNER JOIN sys.objects AS t ON st.object_id = t.object_id
        OUTER APPLY sys.dm_db_stats_properties(st.object_id, st.stats_id) AS sp
        WHERE t.type = ''U'' AND sp.last_updated IS NOT NULL;';

        INSERT INTO @Results
        EXEC(@sql);

        FETCH NEXT FROM db_cursor INTO @db
    END

    CLOSE db_cursor
    DEALLOCATE db_cursor

    SELECT @avg = CEILING(AVG(1.0 * CountValue)) FROM @Results;

    INSERT INTO [dbo].[Statistics] (GreaterSevenDays)
    VALUES (@avg);
END
GO