SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO

CREATE OR ALTER PROCEDURE [dbo].[GetIndexDuplicates]
AS
BEGIN
    SET NOCOUNT ON;

    DECLARE 
        @sql NVARCHAR(MAX),
        @db NVARCHAR(255);

    CREATE TABLE #Counts (AverageDuplicateCount INT);

    DECLARE db_cursor CURSOR FOR
    SELECT name FROM sys.databases
    WHERE state = 0
      AND name NOT IN ('master','model','msdb','tempdb')
      AND source_database_id IS NULL
      AND is_read_only = 0
      AND is_distributor = 0;

    OPEN db_cursor
    FETCH NEXT FROM db_cursor INTO @db

    WHILE @@FETCH_STATUS = 0
    BEGIN
        SET @sql = '
        USE ' + QUOTENAME(@db) + ';
        BEGIN
            WITH IndexDefinition AS (
                SELECT 
                    i.object_id,
                    i.index_id,
                    (
                        SELECT STRING_AGG(CAST(index_column_id AS VARCHAR), '','')
                        FROM sys.index_columns ic
                        WHERE ic.object_id = i.object_id 
                          AND ic.index_id = i.index_id 
                          AND ic.is_included_column = 0
                    ) AS KeyColumns,
                    (
                        SELECT STRING_AGG(CAST(index_column_id AS VARCHAR), '','')
                        FROM sys.index_columns ic
                        WHERE ic.object_id = i.object_id 
                          AND ic.index_id = i.index_id 
                          AND ic.is_included_column = 1
                    ) AS IncludeColumns
                FROM sys.indexes i
                JOIN sys.objects o ON i.object_id = o.object_id
                WHERE o.type = ''U''
                  AND i.is_primary_key = 0 
                  AND i.is_unique_constraint = 0
            ),
            Duplicates AS (
                SELECT 
                    d1.object_id
                FROM IndexDefinition d1
                JOIN IndexDefinition d2
                  ON d1.object_id = d2.object_id
                 AND d1.index_id < d2.index_id
                 AND d1.KeyColumns = d2.KeyColumns
                 AND ISNULL(d1.IncludeColumns, '''') = ISNULL(d2.IncludeColumns, '''')
            )
            INSERT INTO #Counts (AverageDuplicateCount)
            SELECT 
                CASE 
                    WHEN COUNT(DISTINCT object_id) > 0 
                    THEN COUNT(*) / COUNT(DISTINCT object_id) 
                    ELSE 0 
                END
            FROM Duplicates;
        END';

        EXEC(@sql);
        FETCH NEXT FROM db_cursor INTO @db
    END

    CLOSE db_cursor
    DEALLOCATE db_cursor

    INSERT INTO dbo.IndexDuplicates (Average, Max)
    SELECT 
        CAST(AVG(CAST(AverageDuplicateCount AS FLOAT)) AS INT),
        MAX(AverageDuplicateCount)
    FROM #Counts;

    DROP TABLE #Counts;
END
GO