SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO

CREATE OR ALTER PROCEDURE dbo.GetHeaps
AS
BEGIN
    SET NOCOUNT ON;

    DECLARE @db SYSNAME;
    DECLARE @sql NVARCHAR(MAX);
    DECLARE @HeapsCount INT = 0;
    DECLARE @DatabaseCount INT = 0;
    DECLARE @AverageHeapsPerDatabase INT = 0;
    DECLARE @MaxHeapsPerDatabase INT = 0;

    DECLARE @Heaps TABLE (
        [DbName] NVARCHAR(128),
        [TableName] NVARCHAR(128)
    );

    DECLARE @HeapsPerDb TABLE (
        [DbName] NVARCHAR(128),
        HeapCount INT
    );

    DECLARE db_cursor CURSOR FOR
    SELECT name
    FROM sys.databases
    WHERE state = 0
      AND name NOT IN ('master', 'model', 'msdb', 'tempdb')
      AND source_database_id IS NULL
      AND is_read_only = 0
      AND is_distributor = 0;

    OPEN db_cursor;
    FETCH NEXT FROM db_cursor INTO @db;

    WHILE @@FETCH_STATUS = 0
    BEGIN
        SET @sql = '
        SELECT 
            ''' + @db + ''' AS [DbName],
            t.name AS [TableName]
        FROM [' + @db + '].sys.tables t
        INNER JOIN [' + @db + '].sys.schemas s ON t.schema_id = s.schema_id
        WHERE NOT EXISTS (
            SELECT 1
            FROM [' + @db + '].sys.indexes i
            WHERE i.object_id = t.object_id AND i.type = 1
        );';

        INSERT INTO @Heaps ([DbName], [TableName])
        EXEC(@sql);

        INSERT INTO @HeapsPerDb ([DbName], HeapCount)
        SELECT @db, COUNT(*)
        FROM @Heaps
        WHERE [DbName] = @db;

        SET @DatabaseCount += 1;
        FETCH NEXT FROM db_cursor INTO @db;
    END

    CLOSE db_cursor;
    DEALLOCATE db_cursor;

    -- Blacklist anwenden
    DELETE h
    FROM @Heaps h
    JOIN dbo.BlackListHeapTable b
      ON b.[Database] = h.[DbName]
     AND b.[Table] = h.[TableName];

    -- Durchschnitt berechnen
    SELECT @HeapsCount = COUNT(*) FROM @Heaps;

    IF @DatabaseCount > 0
        SET @AverageHeapsPerDatabase = @HeapsCount / @DatabaseCount;

    -- Maximalwert pro Datenbank
    SELECT @MaxHeapsPerDatabase = MAX(HeapCount)
    FROM @HeapsPerDb;

    -- Ergebnis in Tabelle dbo.Heap einfgen
    INSERT INTO dbo.Heap (Average, Max)
    VALUES (@AverageHeapsPerDatabase, @MaxHeapsPerDatabase);
END;
GO