SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO

CREATE OR ALTER PROCEDURE [dbo].[GetFreezes]
AS
BEGIN
    SET NOCOUNT ON;

    DECLARE @FreezeEvents TABLE (
        LogDate DATETIME,
        ProcessInfo NVARCHAR(32),
        [Text] NVARCHAR(MAX)
    );

    INSERT INTO @FreezeEvents
    EXEC xp_readerrorlog 0, 1, N'I/O', NULL, NULL, NULL, N'desc';

    ;WITH OrderedEvents AS (
        SELECT *, ROW_NUMBER() OVER (ORDER BY LogDate DESC) AS rn
        FROM @FreezeEvents
        WHERE [Text] LIKE 'I/O is frozen%' OR [Text] LIKE 'I/O was resumed%'
    ),
    LastFreeze AS (
        SELECT
            Freeze.LogDate AS FreezeStart,
            CEILING(DATEDIFF(SECOND, Freeze.LogDate, Resume.LogDate)) AS FreezeSeconds
        FROM OrderedEvents AS Freeze
        JOIN OrderedEvents AS Resume ON Freeze.rn = Resume.rn + 1
        WHERE 
            Freeze.[Text] LIKE 'I/O is frozen%'
            AND Resume.[Text] LIKE 'I/O was resumed%'
        ORDER BY Freeze.LogDate DESC
        OFFSET 0 ROWS FETCH NEXT 1 ROWS ONLY
    )
    INSERT INTO dbo.Vss (FreezeSeconds)
    SELECT FreezeSeconds
    FROM LastFreeze;
END
GO