SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO

CREATE OR ALTER PROCEDURE dbo.GetIndexFillFactor
AS
BEGIN
    SET NOCOUNT ON;

    IF OBJECT_ID('tempdb..##Results') IS NOT NULL DROP TABLE ##Results;
    CREATE TABLE ##Results (
        DbName SYSNAME,
        [Percent] INT
    );

    DECLARE @dbName SYSNAME, @sql NVARCHAR(MAX);

    DECLARE db_cursor CURSOR FOR
    SELECT name FROM sys.databases
    WHERE state_desc = 'ONLINE'
      AND name NOT IN ('master', 'model', 'msdb', 'tempdb');

    OPEN db_cursor;
    FETCH NEXT FROM db_cursor INTO @dbName;

    WHILE @@FETCH_STATUS = 0
    BEGIN
        SET @sql = '
        DECLARE @cntAll INT, @cntFiltered INT;

        SELECT @cntAll = COUNT(*)
        FROM [' + @dbName + '].sys.indexes i
        JOIN [' + @dbName + '].sys.objects o ON i.object_id = o.object_id
        WHERE o.type = ''U'' AND i.name IS NOT NULL;

        SELECT @cntFiltered = COUNT(*)
        FROM [' + @dbName + '].sys.indexes i
        JOIN [' + @dbName + '].sys.objects o ON i.object_id = o.object_id
        WHERE i.fill_factor > 0 AND i.fill_factor < 100
          AND o.type = ''U''
          AND i.name IS NOT NULL;

        INSERT INTO ##Results (DbName, [Percent])
        SELECT ''' + @dbName + ''',
               CASE WHEN @cntAll = 0 THEN 0 ELSE (@cntFiltered * 100) / @cntAll END;
        ';
        EXEC sp_executesql @sql;
        FETCH NEXT FROM db_cursor INTO @dbName;
    END

    CLOSE db_cursor;
    DEALLOCATE db_cursor;

    DECLARE @avg INT, @max INT;

    SELECT 
        @avg = CAST(AVG(CAST([Percent] AS FLOAT)) AS INT),
        @max = MAX([Percent])
    FROM ##Results;

    INSERT INTO dbo.IndexFillFactor (Average, Max)
    VALUES (@avg, @max);

    DROP TABLE ##Results;
END;
GO