GO
CREATE OR ALTER PROCEDURE [dbo].[PerfGuardDashboard]
    @StartOld DATETIME,
    @EndOld DATETIME,
    @StartNew DATETIME,
    @EndNew DATETIME,
    @ShowHints BIT = NULL
AS
BEGIN
    SET NOCOUNT ON;

    DECLARE 
        @dateLastEdit DATETIME = CAST('09.05.2025' AS DATETIME),
        @cpuOld INT, @cpuNew INT, @cpuOldMax INT, @cpuNewMax INT,
        @ramOld INT, @ramNew INT, @ramOldMax INT, @ramNewMax INT,
        @pressureOld INT, @pressureNew INT,
        @readsDatabaseFilesOld DECIMAL(10,2), @readsDatabaseFilesNew DECIMAL(10,2), @ioDatabaseFilesOld DECIMAL(10,2), @ioDatabaseFilesOldMax DECIMAL(10,2),
        @writesDatabaseFilesOld DECIMAL(10,2), @writesDatabaseFilesNew DECIMAL(10,2), @ioDatabaseFilesNew DECIMAL(10,2), @ioDatabaseFilesNewMax DECIMAL(10,2),     
        @readsTempDbOld DECIMAL(10,2), @readsTempDbNew DECIMAL(10,2), @readsTempDbOldMax DECIMAL(10,2), @readsTempDbNewMax DECIMAL(10,2),
        @writesTempDbOld DECIMAL(10,2), @writesTempDbNew DECIMAL(10,2), @writesTempDbOldMax DECIMAL(10,2), @writesTempDbNewMax DECIMAL(10,2),
        @waitsTopType NVARCHAR(MAX), @waitsOld DECIMAL(10,2), @waitsNew DECIMAL(10,2),
        @readsDatabaseFilesOldAvg INT, @readsDatabaseFilesNewAvg INT, @readsDatabaseFilesOldMax INT ,@readsDatabaseFilesNewMax INT,
        @writesDatabaseFilesOldAvg INT, @writesDatabaseFilesNewAvg INT, @writesDatabaseFilesOldMax INT, @writesDatabaseFilesNewMax INT,
        @planCacheReuseOld DECIMAL(5,2), @planCacheReuseNew DECIMAL(5,2), @planCacheReuseOldWorst DECIMAL(5,2), @planCacheReuseNewWorst DECIMAL(5,2),
        @heapsAvgOld INT, @heapsAvgNew INT, @heapsMaxOld INT, @heapsMaxNew INT, 
        @indexDuplicatesAvgOld INT, @indexDuplicatesAvgNew INT, @indexDuplicatesMaxOld INT, @indexDuplicatesMaxNew INT,
        @indexMissingOld INT, @indexMissingNew INT, @indexMissingMaxOld INT, @indexMissingMaxNew INT,
        @indexUnnecessaryOld INT, @indexUnnecessaryNew INT, @indexUnnecessaryMaxOld INT, @indexUnnecessaryMaxNew INT,
        @vssAvgOld INT, @vssAvgNew INT, @vssMaxOld INT, @vssMaxNew INT,
        @uptimeOld INT, @uptimeNew INT,
        @indexFillFactorOld INT, @indexFillFactorNew INT, @indexFillFactorMaxOld INT, @indexFillFactorMaxNew INT,
        @statsAvgOld INT, @statsAvgNew INT, @statsMaxOld INT, @statsMaxNew INT,
        @queryOld INT, @queryNew INT, @queryOldMax INT, @queryNewMax INT,
        @ord INT = 1;

    DROP TABLE IF EXISTS #DashboardErgebnisse;

    CREATE TABLE #DashboardErgebnisse (
            Ord INT,
            Metrik NVARCHAR(MAX),
            InitialwertDurchschnitt INT,
            InitialwertSchlechtester INT,
            ErgebniswertDurchschnitt INT,
            ErgebniswertSchlechtester INT,
            Trend NVARCHAR(MAX),
            Ampel VARCHAR(MAX),
            AmpelSchlechtester VARCHAR(MAX),
            Hinweis NVARCHAR(MAX),
            Empfehlung NVARCHAR(MAX)
    );

    INSERT INTO #DashboardErgebnisse 
    SELECT 0, 'PerfGuard - SQL Performance Command Center', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL;

    -- CPU
WITH CpuMetrics AS (
    SELECT
        -- CPU
        AVG(CASE WHEN c.Date BETWEEN @StartOld AND @EndOld THEN c.PercentageUsedServer END) AS CpuOldAvg,
        MAX(CASE WHEN c.Date BETWEEN @StartOld AND @EndOld THEN c.PercentageUsedServer END) AS CpuOldMax,
        AVG(CASE WHEN c.Date BETWEEN @StartNew AND @EndNew THEN c.PercentageUsedServer END) AS CpuNewAvg,
        MAX(CASE WHEN c.Date BETWEEN @StartNew AND @EndNew THEN c.PercentageUsedServer END) AS CpuNewMax,

        -- RAM
        AVG(CASE WHEN r.Date BETWEEN @StartOld AND @EndOld THEN r.PercentageUsedServer END) AS RamOldAvg,
        MAX(CASE WHEN r.Date BETWEEN @StartOld AND @EndOld THEN r.PercentageUsedServer END) AS RamOldMax,
        AVG(CASE WHEN r.Date BETWEEN @StartNew AND @EndNew THEN r.PercentageUsedServer END) AS RamNewAvg,
        MAX(CASE WHEN r.Date BETWEEN @StartNew AND @EndNew THEN r.PercentageUsedServer END) AS RamNewMax
    FROM dbo.Cpu c
    CROSS JOIN dbo.Ram r
)
SELECT 
    @cpuOld     = CpuOldAvg,
    @cpuOldMax  = CpuOldMax,
    @cpuNew     = CpuNewAvg,
    @cpuNewMax  = CpuNewMax,

    @ramOld     = RamOldAvg,
    @ramOldMax  = RamOldMax,
    @ramNew     = RamNewAvg,
    @ramNewMax  = RamNewMax
FROM CpuMetrics;

--RAM-Pressure
SELECT @pressureOld = ISNULL(MAX(Pressure), 0) + ISNULL(MAX(GrantsPending), 0) FROM dbo.RamPressure WHERE Date BETWEEN @StartOld AND @EndOld;
SELECT @pressureNew = ISNULL(MAX(Pressure), 0) + ISNULL(MAX(GrantsPending), 0) FROM dbo.RamPressure WHERE Date BETWEEN @StartNew AND @EndNew;

--Vss freezes
SELECT @vssAvgOld = ISNULL(AVG(FreezeSeconds), 0), @vssMaxOld = ISNULL(MAX(FreezeSeconds), 0) FROM dbo.Vss WHERE [Date] BETWEEN @StartOld AND @EndOld;
SELECT @vssAvgNew = ISNULL(AVG(FreezeSeconds), 0), @vssMaxNew = ISNULL(MAX(FreezeSeconds), 0) FROM dbo.Vss WHERE [Date] BETWEEN @StartNew AND @EndNew;

--IndexFillFactor
SELECT @indexFillFactorOld = AVG([Average]) FROM dbo.IndexFillFactor WHERE [Date] BETWEEN @StartOld AND @EndOld;
SELECT @indexFillFactorNew = AVG([Average]) FROM dbo.IndexFillFactor WHERE [Date] BETWEEN @StartNew AND @EndNew;
SELECT @indexFillFactorMaxOld = MAX([Max]) FROM dbo.IndexFillFactor WHERE [Date] BETWEEN @StartOld AND @EndOld;
SELECT @indexFillFactorMaxNew = MAX([Max]) FROM dbo.IndexFillFactor WHERE [Date] BETWEEN @StartNew AND @EndNew;

--Index Missing
SELECT @indexMissingOld = AVG([Average]) FROM dbo.IndexMissing WHERE Date BETWEEN @StartOld AND @EndOld;
SELECT @indexMissingNew = AVG([Average]) FROM dbo.IndexMissing WHERE Date BETWEEN @StartNew AND @EndNew;
SELECT @indexMissingMaxOld = MAX([Max]) FROM dbo.IndexMissing WHERE Date BETWEEN @StartOld AND @EndOld;
SELECT @indexMissingMaxNew = MAX([Max]) FROM dbo.IndexMissing WHERE Date BETWEEN @StartNew AND @EndNew;

--Index Unnecessary
SELECT @indexUnnecessaryOld = AVG(Average) FROM dbo.IndexUnnecessary WHERE Date BETWEEN @StartOld AND @EndOld;
SELECT @indexUnnecessaryNew = AVG(Average) FROM dbo.IndexUnnecessary WHERE Date BETWEEN @StartNew AND @EndNew;
SELECT @indexUnnecessaryMaxOld = MAX(Max) FROM dbo.IndexUnnecessary WHERE Date BETWEEN @StartOld AND @EndOld;
SELECT @indexUnnecessaryMaxNew = MAX(Max) FROM dbo.IndexUnnecessary WHERE Date BETWEEN @StartNew AND @EndNew;

--PlanCache
SELECT @planCacheReuseOld = AVG(Reuse) FROM dbo.PlanCache WHERE Date BETWEEN @StartOld AND @EndOld;
SELECT @planCacheReuseNew = AVG(Reuse) FROM dbo.PlanCache WHERE Date BETWEEN @StartNew AND @EndNew;
SELECT @planCacheReuseOldWorst = MIN(Reuse) FROM dbo.PlanCache WHERE Date BETWEEN @StartOld AND @EndOld;
SELECT @planCacheReuseNewWorst = MIN(Reuse) FROM dbo.PlanCache WHERE Date BETWEEN @StartNew AND @EndNew;
SELECT @uptimeOld = MAX(Uptime) FROM dbo.PlanCache WHERE Date BETWEEN @StartOld AND @EndOld;
SELECT @uptimeNew = MAX(Uptime) FROM dbo.PlanCache WHERE Date BETWEEN @StartNew AND @EndNew;

--Heaps
SELECT @heapsAvgOld = ISNULL(Average, 0) FROM dbo.Heap WHERE Date BETWEEN @StartOld AND @EndOld;
SELECT @heapsAvgNew = ISNULL(Average, 0) FROM dbo.Heap WHERE Date BETWEEN @StartNew AND @EndNew;
SELECT @heapsMaxOld = ISNULL([Max], 0) FROM dbo.Heap WHERE Date BETWEEN @StartOld AND @EndOld;
SELECT @heapsMaxNew = ISNULL([Max], 0) FROM dbo.Heap WHERE Date BETWEEN @StartNew AND @EndNew;

--IndexDuplicates
SELECT @indexDuplicatesAvgOld = ISNULL(AVG(Average), 0) FROM dbo.IndexDuplicates WHERE Date BETWEEN @StartOld AND @EndOld;
SELECT @indexDuplicatesAvgNew = ISNULL(AVG(Average), 0) FROM dbo.IndexDuplicates WHERE Date BETWEEN @StartNew AND @EndNew;
SELECT @indexDuplicatesMaxOld = ISNULL(MAX([Max]), 0) FROM dbo.IndexDuplicates WHERE Date BETWEEN @StartOld AND @EndOld;
SELECT @indexDuplicatesMaxNew = ISNULL(MAX([Max]), 0) FROM dbo.IndexDuplicates WHERE Date BETWEEN @StartNew AND @EndNew;

-- IO
SELECT @readsDatabaseFilesOldAvg = AVG(ReadsAverage) FROM dbo.Io WHERE Date BETWEEN @StartOld AND @EndOld;
SELECT @readsDatabaseFilesNewAvg = AVG(ReadsAverage) FROM dbo.Io WHERE Date BETWEEN @StartNew AND @EndNew;
SELECT @readsDatabaseFilesOldMax = MAX([ReadsMax]) FROM dbo.Io WHERE Date BETWEEN @StartOld AND @EndOld;
SELECT @readsDatabaseFilesNewMax = MAX([ReadsMax]) FROM dbo.Io WHERE Date BETWEEN @StartNew AND @EndNew;
SELECT @writesDatabaseFilesOldAvg = AVG(WritesAverage) FROM dbo.Io WHERE Date BETWEEN @StartOld AND @EndOld;
SELECT @writesDatabaseFilesNewAvg = AVG(WritesAverage) FROM dbo.Io WHERE Date BETWEEN @StartNew AND @EndNew;
SELECT @writesDatabaseFilesOldMax = MAX([WritesMax]) FROM dbo.Io WHERE Date BETWEEN @StartOld AND @EndOld;
SELECT @writesDatabaseFilesNewMax = MAX([WritesMax]) FROM dbo.Io WHERE Date BETWEEN @StartNew AND @EndNew;

    -- TempDB I/O
    ;WITH TempDbAggOld AS (
    SELECT 
        AVG(AvgReadMs) AS ReadAvg,
        MAX(AvgReadMs) AS ReadMax,
        AVG(AvgWriteMs) AS WriteAvg,
        MAX(AvgWriteMs) AS WriteMax
    FROM dbo.TempDbIo
    WHERE Date BETWEEN @StartOld AND @EndOld
),
TempDbAggNew AS (
    SELECT 
        AVG(AvgReadMs) AS ReadAvg,
        MAX(AvgReadMs) AS ReadMax,
        AVG(AvgWriteMs) AS WriteAvg,
        MAX(AvgWriteMs) AS WriteMax
    FROM dbo.TempDbIo
    WHERE Date BETWEEN @StartNew AND @EndNew
)
SELECT 
    @readsTempDbOld = o.ReadAvg,
    @readsTempDbOldMax = o.ReadMax,
    @writesTempDbOld = o.WriteAvg,
    @writesTempDbOldMax = o.WriteMax,
    @readsTempDbNew = n.ReadAvg,
    @readsTempDbNewMax = n.ReadMax,
    @writesTempDbNew = n.WriteAvg,
    @writesTempDbNewMax = n.WriteMax
FROM TempDbAggOld o, TempDbAggNew n;

    -- Wait Stats
    ;WITH RelevanteWaits AS (
        SELECT WaitType, AVG(AvgWaitMs) AS AvgWaitMs
        FROM dbo.Wait
        WHERE Date BETWEEN @StartNew AND @EndNew
		AND WaitType IN (SELECT WaitType FROM WhiteListWaitType)
        GROUP BY WaitType
    )
    SELECT TOP 1 @waitsTopType = WaitType, @waitsNew = AvgWaitMs FROM RelevanteWaits ORDER BY AvgWaitMs DESC;

    SELECT @waitsOld = AVG(AvgWaitMs) FROM dbo.Wait WHERE Date BETWEEN @StartOld AND @EndOld AND WaitType = @waitsTopType;

--Sessions--
DECLARE 
    @sessionsTotalOld DECIMAL(10,2), @sessionsTotalNew DECIMAL(10,2),
    @sessionsTotalOldMax INT, @sessionsTotalNewMax INT,
    @sessionsRunningOld DECIMAL(10,2), @sessionsRunningNew DECIMAL(10,2),
    @sessionsRunningOldMax INT, @sessionsRunningNewMax INT;

-- Total
SELECT 
    @sessionsTotalOld = ISNULL(AVG(Total), 0),
    @sessionsTotalOldMax = ISNULL(MAX(Total), 0)
FROM dbo.Session
WHERE Date BETWEEN @StartOld AND @EndOld;

SELECT 
    @sessionsTotalNew = ISNULL(AVG(Total), 0),
    @sessionsTotalNewMax = ISNULL(MAX(Total), 0)
FROM dbo.Session
WHERE Date BETWEEN @StartNew AND @EndNew;

-- Running
SELECT 
    @sessionsRunningOld = ISNULL(AVG(Running), 0),
    @sessionsRunningOldMax = ISNULL(MAX(Running), 0)
FROM dbo.Session
WHERE Date BETWEEN @StartOld AND @EndOld;

SELECT 
    @sessionsRunningNew = ISNULL(AVG(Running), 0),
    @sessionsRunningNewMax = ISNULL(MAX(Running), 0)
FROM dbo.Session
WHERE Date BETWEEN @StartNew AND @EndNew;

-- Query Duration
SELECT @queryOld = AVG(Average) FROM dbo.Query WHERE [Date] BETWEEN @StartOld AND @EndOld;
SELECT @queryNew = AVG(Average) FROM dbo.Query WHERE [Date] BETWEEN @StartNew AND @EndNew;
SELECT @queryOldMax = MAX(Average) FROM dbo.Query WHERE [Date] BETWEEN @StartOld AND @EndOld;
SELECT @queryNewMax = MAX(Average) FROM dbo.Query WHERE [Date] BETWEEN @StartNew AND @EndNew;

--Statistics
SELECT @statsAvgOld = ISNULL(AVG(GreaterSevenDays), 0) FROM dbo.[Statistics] WHERE Date BETWEEN @StartOld AND @EndOld;
SELECT @statsAvgNew = ISNULL(AVG(GreaterSevenDays), 0) FROM dbo.[Statistics] WHERE Date BETWEEN @StartNew AND @EndNew;
SELECT @statsMaxOld = ISNULL(MAX(GreaterSevenDays), 0) FROM dbo.[Statistics] WHERE Date BETWEEN @StartOld AND @EndOld;
SELECT @statsMaxNew = ISNULL(MAX(GreaterSevenDays), 0) FROM dbo.[Statistics] WHERE Date BETWEEN @StartNew AND @EndNew;

-- Serverbasierte Metriken hinzufgen
INSERT INTO #DashboardErgebnisse
SELECT
        @ord,
        dbo.GetMetricTextByMetricName('CPU'),
        ROUND(@cpuOld, 2) AS Altwert,
        ROUND(@cpuOldMax, 2) AS AltwertSchlechtester,
        ROUND(@cpuNew, 2) AS Neuwert,
        ROUND(@cpuNewMax, 2) AS NeuwertSchlechtester,
        dbo.GetTrend(@cpuOld, @cpuNew, 'CPU'),
        dbo.GetTrafficLightIndicatorStringByMetric('CPU', CAST(@cpuNew AS INT)) AS Ampel,
        dbo.GetTrafficLightIndicatorStringByMetric('CPU', CAST(@cpuNewMax AS INT)) AmpelMax,
        dbo.GetMetricDescriptionByMetric('CPU'),
        dbo.GetHintByMetricName('CPU');
SET @ord = @ord +1;

INSERT INTO #DashboardErgebnisse
SELECT
        @ord,
        dbo.GetMetricTextByMetricName('RAM'), 
        ROUND(@ramOld, 2), 
        ROUND(@ramOldMax, 2), 
        ROUND(@ramNew, 2), 
        ROUND(@ramNewMax, 2), 
        dbo.GetTrend(@ramOld, @ramNew, 'RAM'),
        dbo.GetTrafficLightIndicatorStringByMetric('RAM', CAST(@ramNew AS INT)),
        dbo.GetTrafficLightIndicatorStringByMetric('RAM', CAST(@ramNewMax AS INT)),
        dbo.GetMetricDescriptionByMetric('RAM'), 
        dbo.GetHintByMetricName('RAM');
SET @ord = @ord +1;

INSERT INTO #DashboardErgebnisse
SELECT
    @ord,
    dbo.GetMetricTextByMetricName('Vss'),
    CAST(@vssAvgOld AS DECIMAL(10,2)),
    CAST(@vssMaxOld AS DECIMAL(10,2)),
    CAST(@vssAvgNew AS DECIMAL(10,2)),
    CAST(@vssMaxNew AS DECIMAL(10,2)),
    dbo.GetTrend(@vssAvgOld, @vssAvgNew, 'Vss'),
    dbo.GetTrafficLightIndicatorStringByMetric('Vss', @vssAvgNew),
    dbo.GetTrafficLightIndicatorStringByMetric('Vss', @vssMaxNew),
    dbo.GetMetricDescriptionByMetric('Vss'),
    dbo.GetHintByMetricName('Vss');
SET @ord = @ord + 1;

INSERT INTO #DashboardErgebnisse
SELECT 
    @ord,
    dbo.GetMetricTextByMetricName('Uptime'),
    @uptimeOld,
    @uptimeOld,
    @uptimeNew,
    @uptimeNew,
    dbo.GetTrend(@uptimeOld, @uptimeNew, 'Uptime'),
    dbo.GetTrafficLightIndicatorStringByMetric('Uptime', @uptimeNew),
    dbo.GetTrafficLightIndicatorStringByMetric('Uptime', @uptimeNew),
    dbo.GetMetricDescriptionByMetric('Uptime'),
    dbo.GetHintByMetricName('Uptime');
SET @ord = @ord + 1;

INSERT INTO #DashboardErgebnisse
SELECT
    @ord,
    dbo.GetMetricTextByMetricName('IndexFillFactor'),
    @indexFillFactorOld,
    @indexFillFactorMaxOld,
    @indexFillFactorNew,
    @indexFillFactorMaxNew,
    dbo.GetTrend(@indexFillFactorOld, @indexFillFactorNew, 'IndexFillFactor'),
    dbo.GetTrafficLightIndicatorStringByMetric('IndexFillFactor', @indexFillFactorNew),
    dbo.GetTrafficLightIndicatorStringByMetric('IndexFillFactor', @indexFillFactorMaxNew),
    dbo.GetMetricDescriptionByMetric('IndexFillFactor'),
    dbo.GetHintByMetricName('IndexFillFactor');
SET @ord = @ord + 1;

INSERT INTO #DashboardErgebnisse
SELECT 
        @ord,
        dbo.GetMetricTextByMetricName('Pressure'), 
        @pressureOld, 
        @pressureOld, 
        @pressureNew, 
        @pressureNew, 
        dbo.GetTrend(@pressureOld, @pressureNew, 'Pressure'), 
        dbo.GetTrafficLightIndicatorStringByMetric('Pressure', @pressureNew), 
        dbo.GetTrafficLightIndicatorStringByMetric('Pressure', @pressureNew),
        dbo.GetMetricDescriptionByMetric('Pressure'),
        dbo.GetHintByMetricName('Pressure');
SET @ord = @ord +1;
 
INSERT INTO #DashboardErgebnisse
SELECT 
    @ord,
    dbo.GetMetricTextByMetricName('PlanCache'),
    @planCacheReuseOld,
    @planCacheReuseOldWorst,
    @planCacheReuseNew,
    @planCacheReuseNewWorst,
    dbo.GetTrend(@planCacheReuseOld, @planCacheReuseNew, 'PlanCache'),
    dbo.GetTrafficLightIndicatorStringByMetric('PlanCache', CAST(@planCacheReuseNew AS INT)),
    dbo.GetTrafficLightIndicatorStringByMetric('PlanCache', CAST(@planCacheReuseNewWorst AS INT)),
    dbo.GetMetricDescriptionByMetric('PlanCache'),
    dbo.GetHintByMetricName('PlanCache');
SET @ord = @ord + 1;

INSERT INTO #DashboardErgebnisse
SELECT
    @ord,
    dbo.GetMetricTextByMetricName('Heap'),
    @heapsAvgOld,
    @heapsMaxOld,
    @heapsAvgNew,
    @heapsMaxNew,
    dbo.GetTrend(@heapsAvgOld, @heapsAvgNew, 'Heap'),
    dbo.GetTrafficLightIndicatorStringByMetric('Heap', @heapsAvgNew),
    dbo.GetTrafficLightIndicatorStringByMetric('Heap', @heapsMaxNew),
    dbo.GetMetricDescriptionByMetric('Heap'),
    dbo.GetHintByMetricName('Heap');
SET @ord = @ord + 1;

INSERT INTO #DashboardErgebnisse 
SELECT 
    @ord,
    dbo.GetMetricTextByMetricName('IO_Read'),
    @readsDatabaseFilesOldAvg,
    @readsDatabaseFilesOldMax,
    @readsDatabaseFilesNewAvg,
    @readsDatabaseFilesNewMax,
    dbo.GetTrend(@readsDatabaseFilesOldAvg, @readsDatabaseFilesNewAvg, 'IO_Read'),
    dbo.GetTrafficLightIndicatorStringByMetric('IO_Read', CAST(@readsDatabaseFilesNewAvg AS INT)),
    dbo.GetTrafficLightIndicatorStringByMetric('IO_Read', CAST(@readsDatabaseFilesNewMax AS INT)),
    dbo.GetMetricDescriptionByMetric('IO_Read'),
    dbo.GetHintByMetricName('IO_Read');
SET @ord = @ord +1;

INSERT INTO #DashboardErgebnisse 
SELECT 
    @ord,
    dbo.GetMetricTextByMetricName('IO_Write'),
    @writesDatabaseFilesOldAvg,
    @writesDatabaseFilesOldMax,
    @writesDatabaseFilesNewAvg,
    @writesDatabaseFilesNewMax,
    dbo.GetTrend(@writesDatabaseFilesOldAvg, @writesDatabaseFilesNewAvg, 'IO_Write'),
    dbo.GetTrafficLightIndicatorStringByMetric('IO_Write', CAST(@writesDatabaseFilesNewAvg AS INT)),
    dbo.GetTrafficLightIndicatorStringByMetric('IO_Write', CAST(@writesDatabaseFilesNewMax AS INT)),
    dbo.GetMetricDescriptionByMetric('IO_Write'),
    dbo.GetHintByMetricName('IO_Write');
SET @ord = @ord +1;

INSERT INTO #DashboardErgebnisse 
SELECT 
        @ord,
        dbo.GetMetricTextByMetricName('TempDBRead'), 
        ROUND(@readsTempDbOld, 2), 
        @readsTempDbOldMax, 
        ROUND(@readsTempDbNew, 2), 
        @readsTempDbNewMax, 
        dbo.GetTrend(@readsTempDbOld, @readsTempDbNew, 'TempDBRead'), 
        dbo.GetTrafficLightIndicatorStringByMetric('TempDBRead', CAST(@readsTempDbNew AS INT)), 
        dbo.GetTrafficLightIndicatorStringByMetric('TempDBRead', CAST(@readsTempDbNewMax AS INT)),
        dbo.GetMetricDescriptionByMetric('TempDBRead'), 
        dbo.GetHintByMetricName('TempDBRead');
SET @ord = @ord +1;

INSERT INTO #DashboardErgebnisse
SELECT
        @ord,
        dbo.GetMetricTextByMetricName('TempDBWrite'),
        ROUND(@writesTempDbOld, 2), 
        @writesTempDbOldMax, 
        ROUND(@writesTempDbNew, 2), 
        @writesTempDbNewMax, 
        dbo.GetTrend(@writesTempDbOld, @writesTempDbNew, 'TempDBWrite'), 
        dbo.GetTrafficLightIndicatorStringByMetric('TempDBWrite', CAST(@writesTempDbNew AS INT)), 
        dbo.GetTrafficLightIndicatorStringByMetric('TempDBWrite', CAST(@writesTempDbNewMax AS INT)), 
        dbo.GetMetricDescriptionByMetric('TempDBWrite'), 
        dbo.GetHintByMetricName('TempDBWrite');
SET @ord = @ord +1;

INSERT INTO #DashboardErgebnisse
SELECT 
        @ord,
        dbo.GetMetricTextByMetricName('WaitStats'),
        ROUND(@waitsOld, 2), 
        ROUND(@waitsOld, 2), 
        ROUND(@waitsNew, 2), 
        ROUND(@waitsNew, 2), 
        dbo.GetTrend(@waitsOld, @waitsNew, 'WaitStats'),  
        dbo.GetTrafficLightIndicatorStringByMetric('WaitStats', CAST(@waitsNew AS INT)),
        dbo.GetTrafficLightIndicatorStringByMetric('WaitStats', CAST(@waitsNew AS INT)),
        dbo.GetMetricDescriptionByMetric('WaitStats'), 
        dbo.GetWaitTypeExplanation(@waitsTopType, @waitsNew);
SET @ord = @ord +1;

INSERT INTO #DashboardErgebnisse
SELECT
    @ord,
    dbo.GetMetricTextByMetricName('SessionsTotal'),
    @sessionsTotalOld,
    @sessionsTotalOldMax,
    @sessionsTotalNew,
    @sessionsTotalNewMax,
    dbo.GetTrend(@sessionsTotalOld, @sessionsTotalNew, 'SessionsTotal'),
    dbo.GetTrafficLightIndicatorStringByMetric('SessionsTotal', CAST(@sessionsTotalNew AS INT)),
    dbo.GetTrafficLightIndicatorStringByMetric('SessionsTotal', CAST(@sessionsTotalNewMax AS INT)),
    dbo.GetMetricDescriptionByMetric('SessionsTotal'),
    dbo.GetHintByMetricName('SessionsTotal');
SET @ord = @ord +1;

INSERT INTO #DashboardErgebnisse
SELECT
    @ord,
    dbo.GetMetricTextByMetricName('SessionsRunning'),
    @sessionsRunningOld,
    @sessionsRunningOldMax,
    @sessionsRunningNew,
    @sessionsRunningNewMax,
    dbo.GetTrend(@sessionsRunningOld, @sessionsRunningNew, 'SessionsRunning'),
    dbo.GetTrafficLightIndicatorStringByMetric('SessionsRunning', CAST(@sessionsRunningNew AS INT)),
    dbo.GetTrafficLightIndicatorStringByMetric('SessionsRunning', CAST(@sessionsRunningNewMax AS INT)),
    dbo.GetMetricDescriptionByMetric('SessionsRunning'),
    dbo.GetHintByMetricName('SessionsRunning');
SET @ord = @ord +1;

INSERT INTO #DashboardErgebnisse
SELECT
    @ord,
    dbo.GetMetricTextByMetricName('Query'),
    @queryOld,
    @queryOldMax,
    @queryNew,
    @queryNewMax,
    dbo.GetTrend(@queryOld, @queryNew, 'Query'),
    dbo.GetTrafficLightIndicatorStringByMetric('Query', CAST(@queryNew AS INT)),
    dbo.GetTrafficLightIndicatorStringByMetric('Query', CAST(@queryNewMax AS INT)),
    dbo.GetMetricDescriptionByMetric('Query'),
    dbo.GetHintByMetricName('Query');
SET @ord = @ord + 1;

INSERT INTO #DashboardErgebnisse
SELECT
    @ord,
    dbo.GetMetricTextByMetricName('IndexMissing'),
    @indexMissingOld,
    @indexMissingMaxOld,
    @indexMissingNew,
    @indexMissingMaxNew,
    dbo.GetTrend(@indexMissingOld, @indexMissingNew, 'IndexMissing'),
    dbo.GetTrafficLightIndicatorStringByMetric('IndexMissing', @indexMissingNew),
    dbo.GetTrafficLightIndicatorStringByMetric('IndexMissing', @indexMissingMaxNew),
    dbo.GetMetricDescriptionByMetric('IndexMissing'),
    dbo.GetHintByMetricName('IndexMissing');
SET @ord = @ord + 1;

INSERT INTO #DashboardErgebnisse
SELECT
    @ord,
    dbo.GetMetricTextByMetricName('IndexUnnecessary'),
    CAST(@indexUnnecessaryOld AS DECIMAL(10,2)),
    CAST(@indexUnnecessaryMaxOld AS DECIMAL(10,2)),
    CAST(@indexUnnecessaryNew AS DECIMAL(10,2)),
    CAST(@indexUnnecessaryMaxNew AS DECIMAL(10,2)),
    dbo.GetTrend(@indexUnnecessaryOld, @indexUnnecessaryNew, 'IndexUnnecessary'),
    dbo.GetTrafficLightIndicatorStringByMetric('IndexUnnecessary', @indexUnnecessaryNew),
    dbo.GetTrafficLightIndicatorStringByMetric('IndexUnnecessary', @indexUnnecessaryMaxNew),
    dbo.GetMetricDescriptionByMetric('IndexUnnecessary'),
    dbo.GetHintByMetricName('IndexUnnecessary');
SET @ord = @ord + 1;

INSERT INTO #DashboardErgebnisse
SELECT
    @ord,
    dbo.GetMetricTextByMetricName('IndexDuplicates'),
    @indexDuplicatesAvgOld,
    @indexDuplicatesMaxOld,
    @indexDuplicatesAvgNew,
    @indexDuplicatesMaxNew,
    dbo.GetTrend(@indexDuplicatesAvgOld, @indexDuplicatesAvgNew, 'IndexDuplicates'),
    dbo.GetTrafficLightIndicatorStringByMetric('IndexDuplicates', @indexDuplicatesAvgNew),
    dbo.GetTrafficLightIndicatorStringByMetric('IndexDuplicates', @indexDuplicatesMaxNew),
    dbo.GetMetricDescriptionByMetric('IndexDuplicates'),
    dbo.GetHintByMetricName('IndexDuplicates');
SET @ord = @ord + 1;

INSERT INTO #DashboardErgebnisse
SELECT
    @ord,
    dbo.GetMetricTextByMetricName('Statistics'),
    @statsAvgOld,
    @statsMaxOld,
    @statsAvgNew,
    @statsMaxNew,
    dbo.GetTrend(@statsAvgOld, @statsAvgNew, 'Statistics'),
    dbo.GetTrafficLightIndicatorStringByMetric('Statistics', @statsAvgNew),
    dbo.GetTrafficLightIndicatorStringByMetric('Statistics', @statsMaxNew),
    dbo.GetMetricDescriptionByMetric('Statistics'),
    dbo.GetHintByMetricName('Statistics');
SET @ord = @ord + 1;

INSERT INTO #DashboardErgebnisse
SELECT @ord, 'http://www.agileinformer.de', NULL, NULL, NULL, NULL, NULL, NULL, NULL, 'Version vom ' + FORMAT(@dateLastEdit, 'dd.MM.yyyy', 'de-DE'), NULL;
SET @ord = @ord +1;

    IF (DATEADD(mm, -6, GETDATE()) > @dateLastEdit)
    BEGIN
        INSERT INTO #DashboardErgebnisse
        SELECT 0, '!!! ALTE VERSION !!!', NULL, NULL, NULL, NULL, NULL, NULL, NULL, '!!! ALTE VERSION !!! -->', 'Prfen Sie, ob eine neuere Version existiert, unter: http://www.agileinformer.de';
    END

    IF (@ShowHints = 1)
    BEGIN
        SELECT
            Metrik,
            InitialwertDurchschnitt,
            InitialwertSchlechtester,
            ErgebniswertDurchschnitt,
            ErgebniswertSchlechtester,
            Trend,
            Ampel,
            AmpelSchlechtester,
            Hinweis,
            Empfehlung
        FROM #DashboardErgebnisse
        ORDER BY Ord;
        DROP TABLE #DashboardErgebnisse;
        RETURN;
    END

    IF (@ShowHints = 0)
    BEGIN
        SELECT
            Metrik,
            InitialwertDurchschnitt,
            InitialwertSchlechtester,
            ErgebniswertDurchschnitt,
            ErgebniswertSchlechtester,
            Trend,
            Ampel,
            AmpelSchlechtester
        FROM #DashboardErgebnisse
        ORDER BY Ord;
        DROP TABLE #DashboardErgebnisse;
        RETURN;
    END

    DROP TABLE #DashboardErgebnisse;
END;
GO